@@ -42,7 +42,8 @@ class Escrow:
                 for tx in txs:
                     msg = tx.signature_message_fragment.decode()
                     try:
-                        return Address(msg.strip())
+                        self.deposit = Address(msg.strip())
+                        return self.deposit
                     except: pass
                 logging.warning("Invalid address recieved")
         except requests.exceptions.ConnectionError as e:
@@ -84,8 +85,9 @@ class Escrow:
         return True
 
     #Refund user their collateral, remoing the fee
-    def finalizeEscrow(self,fee=None):
+    def finalizeEscrow(self,fee=None,deposit=None):
         if fee is None: fee=self.fee
+        if deposit is None: deposit = self.deposit
         #Return money to deposit address
         returnAmount=self.getBalance(self.holdingAddress)
         
@@ -98,7 +100,7 @@ class Escrow:
         feeLocation = self.api.get_new_addresses(count=1,checksum=True)['addresses'][0]
         txs = [
             ProposedTransaction(
-                address = Address(self.deposit),
+                address = Address(deposit),
                 value = returnAmount,
                 message = TryteString.from_unicode(message)
             ),
